
import os
from datetime import datetime
from cement.utils import fs, shell
from boss.cli.template import TemplateManager
from boss.core import exc

class SourceManager(object):
    def __init__(self, app):
        self.app = app

    def sync(self, source):
        sources = self.app.db['sources']
        src = self.app.db['sources'][source]

        if not src['is_local']:
            if not os.path.exists(os.path.join(src['cache'], '.git')):
                shell.exec_cmd2([ 'git', 'clone',
                                src['path'], src['cache'] ])
            else:
                orig_dir = fs.abspath(os.curdir)
                try:
                    os.chdir(src['cache'])
                    shell.exec_cmd2(['git', 'pull'])
                    os.chdir(orig_dir)
                finally:
                    os.chdir(orig_dir)

        src['last_sync_time'] = datetime.now()
        sources[source] = src
        self.app.db['sources'] = sources

    def get_templates(self, source):
        templates = []
        src = self.app.db['sources'][source]

        if src['is_local']:
            basedir = src['path']
        else:
            basedir = src['cache']

        for entry in os.listdir(basedir):
            full_path = os.path.join(basedir, entry)
            if entry.startswith('.'):
                continue
            elif os.path.isdir(full_path):
                templates.append(entry)
        return templates

    def create_from_template(self, source, template, dest_dir):
        try:
            src = self.app.db['sources'][source]
        except KeyError as e:
            raise exc.BossTemplateError("Source repo '%s' " % source + \
                                        "does not exist.")

        if src['is_local']:
            basedir = os.path.join(src['path'], template)
        else:
            basedir = os.path.join(src['cache'], template)

        tmpl = TemplateManager(self.app, fs.abspath(basedir))
        tmpl.copy(dest_dir)



"""Boss core exceptions module."""

class BossError(Exception):
    """Generic errors."""
    def __init__(self, msg):
        Exception.__init__(self)
        self.msg = msg

    def __str__(self):
        return self.msg


class BossConfigError(BossError):
    pass

class BossRuntimeError(BossError):
    pass

class BossArgumentError(BossError):
    pass

class BossTemplateError(BossError):
    pass

class BossSourceError(BossError):
    pass




import os
import sys
import shutil
import re
from tempfile import mkdtemp
from cement.core.controller import CementBaseController, expose
from cement.utils import fs
from boss import VERSION
from boss.core import exc as boss_exc
from boss.cli.source import SourceManager

BANNER = """

  _______  _______ _______ _______
 |   _   \|   _   |   _   |   _   |
 |.  1   /|.  |   |   1___|   1___|
 |.  _   \|.  |   |____   |____   |
 |:  1    |:  1   |:  1   |:  1   |
 |::.. .  |::.. . |::.. . |::.. . |
 `-------'`-------`-------`-------'
      (c) 2014 Data Folk Labs, LLC
                           v%s

""" % VERSION

class BossBaseController(CementBaseController):
    class Meta:
        label = 'base'
        description = 'Boss Templates and Development Utilities'
        arguments = [
            (['-t', '--template'],
             dict(help="a template label", dest='template')),
            (['--local'],
             dict(help='toggle a local source repository',
                  action='store_true', default=False)),
            (['--version'], dict(action='version', version=BANNER)),
            (['--defaults'],
             dict(action='store_true',
                  help='use default answers without prompting')),
            (['extra'],
             dict(help='additional positional arguments',
                  action='store', nargs='*')),
            ]
        config_defaults = dict()

    @expose(hide=True)
    def default(self):
        raise boss_exc.BossArgumentError("A sub-command is required.  "
                                         "Please see --help.")

    @expose(help="create project files from a template")
    def create(self):
        if not len(self.app.pargs.extra) >= 1:
            raise boss_exc.BossArgumentError("Destination path required.")

        if not self.app.pargs.template:
            raise boss_exc.BossArgumentError("Template label required.")

        sources = self.app.db.get('sources')

        try:
            tmpl_parts = self.app.pargs.template.split(':')
            source = tmpl_parts[0]
            template = tmpl_parts[1]
        except IndexError as e:
            source = 'boss'
            template = self.app.pargs.template

        src = SourceManager(self.app)
        src.create_from_template(source, template, self.app.pargs.extra[0])

    @expose(help="list all available templates")
    def templates(self):
        print('')
        sources = self.app.db['sources']
        for label,data in sources.items():
            print("Source: %s" % label)
            print('-' * 78)
            if data['is_local'] is True:
                local_path = sources[label]
                remote_path = None
            else:
                local_path = "%s/templates/%s" % (
                            self.app.config.get('boss', 'data_dir'), label,
                            )
                remote_path = sources[label]

            src = SourceManager(self.app)
            for tmpl in src.get_templates(label):
                print(tmpl)

            print('')

    @expose(help="sync a source repository")
    def sync(self):
        _sources = self.app.db['sources']
        for label in self.app.db['sources']:
            print("Syncing %s Templates . . . " % label.capitalize())
            src = SourceManager(self.app)
            src.sync(label)
            print('')

    @expose(help="list template source repositories")
    def sources(self):
        for key in self.app.db['sources']:
            src = self.app.db['sources'][key]
            print('')
            print("--        Label: %s" % src['label'])
            print("    Source Path: %s" % src['path'])
            print("          Cache: %s" % src['cache'])
            print("     Local Only: %s" % src['is_local'])
            print(" Last Sync Time: %s" % src['last_sync_time'])
        print('')

    @expose(help="add a template source repository")
    def add_source(self):
        if not len(self.app.pargs.extra) >= 2:
            raise boss_exc.BossArgumentError("Repository name and path " + \
                                             "required.")

        sources = self.app.db['sources']
        label = self.app.pargs.extra[0]
        path = self.app.pargs.extra[1]
        cache_dir = mkdtemp(dir=self.app.config.get('boss', 'cache_dir'))

        if self.app.pargs.local:
            path = fs.abspath(path)

        sources[label] = dict(
            label=label,
            path=path,
            cache=cache_dir,
            is_local=self.app.pargs.local,
            last_sync_time='never'
            )
        self.app.db['sources'] = sources

    @expose(help="remove a source repository")
    def rm_source(self):
        sources = self.app.db['sources']

        if not len(self.app.pargs.extra) >= 1:
            raise boss_exc.BossArgumentError("Repository name required.")
        elif self.app.pargs.extra[0] not in sources:
            raise boss_exc.BossArgumentError("Unknown source repository.")

        cache = sources[self.app.pargs.extra[0]]['cache']
        if os.path.exists(cache):
            shutil.rmtree(cache)

        del sources[self.app.pargs.extra[0]]
        self.app.db['sources'] = sources

    @expose(help="remove .boss.bak* files from path")
    def clean(self):
        if not len(self.app.pargs.extra) >= 1:
            raise boss_exc.BossArgumentError("Project path required.")
        for items in os.walk(self.app.pargs.extra[0]):
            for _file in items[2]:
                path = fs.abspath(os.path.join(items[0], _file))
                if re.match('(.*)\.boss\.bak(.*)', path):
                    self.app.log.warn("Removing: %s" % _file)
                    os.remove(path)






import os
import shelve
from tempfile import mkdtemp
from cement.core import hook, handler
from cement.utils import fs

def setup_db(app):
    app.extend('db', shelve.open(app.config.get('boss', 'db_path')))
    if 'sources' not in app.db.keys():
        cache_dir = fs.abspath(mkdtemp(dir=app.config.get('boss', 'cache_dir')))

        app.db['sources'] = dict()
        sources = app.db['sources']
        sources['boss'] = dict(
            label='boss',
            path='https://github.com/derks/boss-templates.git',
            cache=cache_dir,
            is_local=False,
            last_sync_time='never'
            )
        app.db['sources'] = sources

    if 'templates' not in app.db.keys():
        app.db['templates'] = dict()

def cleanup(app):
    if hasattr(app, 'db'):
        app.db.close()

def load(app):
    hook.register('post_setup', setup_db)
    hook.register('pre_close', cleanup)




import os
import sys
from tempfile import mkdtemp
from cement.core import foundation
from cement.core import exc as cement_exc
from cement.utils import fs, misc
from boss.cli.controllers.base import BossBaseController
from boss.core import exc as boss_exc

if sys.version_info[0] >= 3:
    from imp import reload      # pragma: nocover

defaults = misc.init_defaults('boss', 'answers')
defaults['boss']['data_dir'] = '~/.boss/'

class BossApp(foundation.CementApp):
    class Meta:
        label = 'boss'
        bootstrap = 'boss.cli.bootstrap'
        base_controller = BossBaseController
        config_defaults = defaults
        config_files = [
            '/etc/boss/boss.conf',
            '~/.boss.conf',
            '~/.boss/config',
            ]

    def validate_config(self):
        # fix up paths
        self.config.set('boss', 'data_dir',
                        fs.abspath(self.config.get('boss', 'data_dir')))

        # create directories
        if not os.path.exists(self.config.get('boss', 'data_dir')):
            os.makedirs(self.config.get('boss', 'data_dir'))

        # add shortcuts
        pth = os.path.join(self.config.get('boss', 'data_dir'), 'cache')
        if not os.path.exists(fs.abspath(pth)):
            os.makedirs(fs.abspath(pth))
        self.config.set('boss', 'cache_dir', pth)

        pth = os.path.join(self.config.get('boss', 'data_dir'), 'boss.db')
        self.config.set('boss', 'db_path', pth)

def main(argv=None):
    if argv is None:
        argv = sys.argv[1:]

    app = BossApp(argv=argv)
    try:
        app.setup()
        app.run()
    except boss_exc.BossTemplateError as e:
        print("BossTemplateError: %s" % e.msg)
    except boss_exc.BossArgumentError as e:
        print("BossArgumentError: %s" % e.msg)
    except cement_exc.CaughtSignal as e:        # pragma: nocover
        print(e)                                # pragma: nocover
    except cement_exc.FrameworkError as e:      # pragma: nocover
        print(e)                                # pragma: nocover

    app.close()

test_tmpdir = mkdtemp()
def get_test_app(**kw):
    test_defaults = defaults
    test_defaults['boss']['data_dir'] = test_tmpdir
    kw['config_defaults'] = kw.get('config_defaults', test_defaults)
    kw['config_files'] = kw.get('config_files', [])

    app = BossApp(**kw)
    return app

if __name__ == '__main__':
    main()  # pragma: nocover




from setuptools import setup, find_packages
import sys, os

setup(name='@module@',
    version='@version@',
    description="@description@",
    long_description="@description@",
    classifiers=[], 
    keywords='',
    author='@creator@',
    author_email='@email@',
    url='@url@',
    license='@license@',
    packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
    include_package_data=True,
    zip_safe=False,
    test_suite='nose.collector',
    install_requires=[
        ### Required to build documentation
        # "Sphinx >= 1.0",
        ### Required for testing
        # "nose",
        # "coverage",
        ],
    setup_requires=[],
    entry_points="""
    """,
    namespace_packages=[],
    )




import os
import sys
import re
import json
from cement.utils import fs
from boss.core import exc as boss_exc

if sys.version_info[0] < 3:
    from urllib2 import urlopen, HTTPError # pragma: no cover
    from ConfigParser import RawConfigParser  # pragma: no cover
else:
    from urllib.request import urlopen, HTTPError # pragma: no cover
    from configparser import RawConfigParser  # pragma: no cover

ALLOWED_STR_METHODS = [
    'upper',
    'lower',
    'title',
    'swapcase',
    'strip',
    'capitalize'
]

class TemplateManager(object):
    def __init__(self, app, path):
        self.app = app
        self.basedir = fs.abspath(path)
        self.config = self._get_config()
        self._word_map = dict()
        self._vars = dict()

    def _get_config(self):
        config = None
        possibles = [
            fs.abspath(os.path.join(self.basedir, 'boss.json')),
            fs.abspath(os.path.join(self.basedir, 'boss.yml')),
            ]

        for path in possibles:
            if os.path.exists(path):
                if os.path.basename(path) == 'boss.json':
                    config = self._get_json_config(path)
                    break
                elif os.path.basename(path) == 'boss.yml':
                    config = self._get_yaml_config(path)
                    break

        if not config:
            raise boss_exc.BossTemplateError("No supported config found.")

        # fix it up with some defaults
        if 'delimiter' not in config.keys():
            config['delimiter'] = '@'

        return config

    def _get_json_config(self, path):
        full_path = fs.abspath(path)
        if not os.path.exists(full_path):
            raise boss_exc.BossTemplateError("Invalid template config.")

        self.app.log.debug('loading template config %s' % full_path)

        import json
        return json.load(open(full_path, 'r'))

    def _get_yaml_config(self, path):
        full_path = fs.abspath(path)
        if not os.path.exists(full_path):
            raise boss_exc.BossTemplateError("Invalid template config.")

        self.app.log.debug('loading template config %s' % full_path)

        try:
            import yaml
        except ImportError as e:
            raise boss_exc.BossRuntimeError("Unable to import yaml.  " +
                                            "Please install pyYaml.")

        return yaml.load(open(full_path, 'r'))

    def _populate_vars(self):
        if 'variables' in self.config.keys():
            for var,question in self.config['variables'].items():
                if self.app.pargs.defaults is True:
                    try:
                        res = self.app.config.get('answers', var)
                    except ConfigParser.NoOptionError as e:
                        res = "MISSING VARIABLE"
                else:
                    if var.lower() in self.app.config.keys('answers'):
                        default = self.app.config.get('answers', var.lower())
                        res = raw_input("%s: [%s] " % (question, default))
                        if len(res) == 0:
                            res = default
                    else:
                        res = raw_input("%s: " % question)
                self._vars[var] = res.strip()

    def _sub(self, txt):
        ### FIX ME: This needs serious refactoring... PLEASE

        # do per item substitution rather than entire txt to avoid variable
        # confusion.  Also allows us to call .capitalize, .lower, etc on the
        # string after substitution.
        for line in str(txt).split('\n'):
            for item in line.split(' '):
                # Not a template var? (generic pattern)
                pattern = "(.*)\%s(.*)\%s(.*)" % \
                    (self.config['delimiter'], self.config['delimiter'])

                if not re.match(pattern, item):
                    continue

                for key,value in sorted(self._vars.items()):
                    if key in self._word_map:
                        continue

                    pattern = "(.*)\%s(%s)\%s(.*)" % (
                        self.config['delimiter'],
                        key,
                        self.config['delimiter'],
                        )

                    m = re.match(pattern, item)
                    if m:
                        map_key = "%s%s%s" % (
                            self.config['delimiter'],
                            m.group(2),
                            self.config['delimiter'],
                            )
                        self._word_map[map_key] = str(value)
                    else:
                        pattern = "(.*)\%s(%s)\.([_a-z0-9]*)\%s(.*)" % (
                            self.config['delimiter'],
                            key,
                            self.config['delimiter'],
                            )
                        m = re.match(pattern, item)
                        if m:
                            # string method calls?
                            if len(m.group(3)) > 0:
                                if m.group(3) in ALLOWED_STR_METHODS:
                                    fixed = str(getattr(value, m.group(3))())
                                else:
                                    self.app.log.debug("str method '%s' not allowed." % m.group(3))
                                    fixed = str(value)
                            else:
                                fixed = str(value)

                            new_key = "%s%s.%s%s" % (
                                self.config['delimiter'],
                                m.group(2),
                                m.group(3),
                                self.config['delimiter'],
                                )
                            self._word_map[new_key] = fixed

        # actually replace the text
        new_txt = str(txt)
        for pattern,replacement in sorted(self._word_map.items()):
            new_txt = re.sub(pattern, replacement, new_txt)

        return new_txt

    def _sub_or_pass(self, path, data):
        if 'excludes' in self.config.keys():
            for pattern in self.config['excludes']:
                if re.match(pattern, path):
                    self.app.log.debug(
                        "not doing substitutions for excluded %s" % path
                        )
                    # don't do subs
                    return data
        return self._sub(data)

    def _inject(self, dest_path):
        new_data = ''
        write_it = False

        f = open(dest_path, 'r')
        line_num = 0
        for line in f.readlines():
            line_num = line_num + 1
            # only one injection per line is allowed
            for inj,inj_data in self.config['injections'].items():
                pattern = '(.*)\%sboss.mark\:%s\%s(.*)' % (
                    self.config['delimiter'],
                    inj,
                    self.config['delimiter'],
                    )
                m = re.match(pattern, line)
                if m:
                    print("Injecting %s into %s at line #%s" % \
                         (inj, dest_path, line_num))
                    line = line + "%s\n" % self._sub(inj_data)
                    write_it = True
                    break

            new_data = new_data + line
        f.close()

        if write_it:
            fs.backup(dest_path, suffix='.boss.bak')
            self._write_file(dest_path, new_data, overwrite=True)

    def _inject_or_pass(self, path):
        if 'excludes' in self.config.keys():
            for pattern in self.config['excludes']:
                if re.match(pattern, path):
                    self.app.log.debug(
                        "not doing injections for excluded %s" % path
                        )
                    return False
        return self._inject(path)
        return True

    def _copy_path(self, tmpl_path, dest_path):
        f = open(fs.abspath(tmpl_path), 'r')
        data = f.read()
        f.close()

        dest_path = self._sub(fs.abspath(dest_path))
        dest_data = self._sub_or_pass(tmpl_path, data)
        self._write_file(dest_path, dest_data)

    def _write_file(self, dest_path, data, overwrite=False):
        if os.path.exists(dest_path) and overwrite == False:
            self.app.log.warn('File Exists: %s' % dest_path)
            return False

        self.app.log.info('Writing: %s' % dest_path)
        if not os.path.exists(os.path.dirname(dest_path)):
            os.makedirs(os.path.dirname(dest_path))
        f = open(dest_path, 'w')
        f.write(data)
        f.close()
        return True

    def _walk_path(self, path):
        for items in os.walk(fs.abspath(path)):
            for _file in items[2]:
                if _file == 'boss.yml':
                    continue
                elif re.match('(.*)\.boss\.bak(.*)', _file):
                    continue
                else:
                    yield fs.abspath(os.path.join(items[0], _file))

    def copy(self, dest_basedir):
        self._populate_vars()
        dest_basedir = fs.abspath(dest_basedir)

        # first handle local files
        for tmpl_path in self._walk_path(self.basedir):
            dest_path = fs.abspath(re.sub(self.basedir, dest_basedir, tmpl_path))
            self._copy_path(tmpl_path, dest_path)

        # second handle external files
        if 'external_files' in self.config.keys():
            for _file, remote_uri in self.config['external_files'].items():
                dest_path = self._sub(os.path.join(dest_basedir, _file))
                remote_uri = self._sub(remote_uri)
                try:
                    data = self._sub(urlopen(remote_uri).read())
                except HTTPError as e:
                    data = ''

                self._write_file(dest_path, data)

        # lastly do injections
        if 'injections' in self.config.keys() \
            and len(self.config['injections']) > 0:
            for dest_path in self._walk_path(dest_basedir):
                self._inject_or_pass(dest_path)




import os
import sys
import shutil
from tempfile import mkdtemp
from cement.core import backend
from cement.utils import test, shell
import boss
from boss.cli.main import get_test_app
from boss.core import exc

class CLITestCase(test.CementTestCase):
    ### FIX ME: This should be a remote.. but is a failed process... using
    ### local
    def test_00_add_source(self):
        app = get_test_app(
            argv=['add-source', 'test', './tests/templates', '--local'])
        app.setup()
        app.run()
        app.close()

    def test_01_add_local_source(self):
        # get real sources for our local source
        app = get_test_app(argv=['sources'])
        app.setup()
        app.run()
        local = app.db['sources']['test']['cache']
        app.close()

        app = get_test_app(argv=['add-source', 'test-local', local,
                                 '--local'])
        app.setup()
        app.run()
        app.close()

    @test.raises(exc.BossArgumentError)
    def test_add_source_bad_arguments(self):
        try:
            app = get_test_app(argv=['add-source'])
            app.setup()
            app.run()
        except exc.BossArgumentError as e:
            self.eq(e.msg, "Repository name and path required.")
            raise
        finally:
            app.close()

    def test_01_sync(self):
        app = get_test_app(argv=['sync'])
        app.setup()
        app.run()
        app.close()

        # sync again for coverage
        app = get_test_app(argv=['sync'])
        app.setup()
        app.run()
        app.close()

    def test_list_sources(self):
        app = get_test_app(argv=['sources'])
        app.setup()
        app.run()
        app.close()

    def test_list_templates(self):
        app = get_test_app(argv=['templates'])
        app.setup()
        app.run()
        app.close()

    @test.raises(exc.BossArgumentError)
    def test_default(self):
        try:
            app = get_test_app(argv=[''])
            app.setup()
            app.run()
        finally:
            app.close()

    @test.raises(exc.BossArgumentError)
    def test_create_bad_destination(self):
        try:
            app = get_test_app(argv=['create'])
            app.setup()
            app.run()
        except exc.BossArgumentError as e:
            test.eq(e.msg, "Destination path required.")
            raise
        finally:
            app.close()

    @test.raises(exc.BossArgumentError)
    def test_create_missing_template(self):
        try:
            app = get_test_app(argv=['create', self.tmp_dir])
            app.setup()
            app.run()
        except exc.BossArgumentError as e:
            test.eq(e.msg, "Template label required.")
            raise
        finally:
            app.close()

    # def test_create(self):
    #     try:
    #         answers = dict(
    #             version='0.9.1',
    #             module='test_python_module',
    #             project='Test Pyton Project',
    #             description='Project Description',
    #             creator='Project Creator',
    #             email='nobody@example.com',
    #             license='BSD',
    #             url='http://project.example.com',
    #             )
    #         app = get_test_app(
    #             argv=[
    #                 'create',
    #                 '%s/dest' % self.tmp_dir,
    #                 '-t',
    #                 'test:python',
    #                 '--defaults',
    #                 ],
    #             )
    #         app.setup()
    #         app.config.merge(dict(answers=answers))
    #         app.run()
    #     finally:
    #         app.close()

    def test_create_from_local_source(self):
        try:
            answers = dict(
                version='0.9.1',
                module='test_python_module',
                project='Test Pyton Project',
                description='Project Description',
                creator='Project Creator',
                email='nobody@example.com',
                license='BSD',
                url='http://project.example.com',
                )
            app = get_test_app(
                argv=[
                    'create',
                    '%s/dest' % self.tmp_dir,
                    '-t',
                    'test:python',
                    '--defaults',
                    ],
                )
            app.setup()
            app.config.merge(dict(answers=answers))
            app.run()
        finally:
            app.close()

    def test_create_default_source(self):
        try:
            answers = dict(
                version='0.9.1',
                module='test_python_module',
                project='Test Pyton Project',
                description='Project Description',
                creator='Project Creator',
                email='nobody@example.com',
                license='BSD',
                url='http://project.example.com',
                )
            app = get_test_app(
                argv=[
                    'create',
                    '%s/dest' % self.tmp_dir,
                    '-t',
                    'python',
                    '--defaults',
                    ],
                )
            app.setup()
            app.config.merge(dict(answers=answers))
            app.run()
        finally:
            app.close()

    def test_cli(self):
        app = get_test_app(argv=['templates'])
        app.setup()
        app.run()
        app.close()

    def test_rm_source(self):
        app = get_test_app(argv=['rm-source', 'test'])
        app.setup()
        app.run()
        app.close()

    @test.raises(exc.BossArgumentError)
    def test_rm_source_no_label(self):
        try:
            app = get_test_app(argv=['rm-source'])
            app.setup()
            app.run()
            app.close()
        except exc.BossArgumentError as e:
            self.eq(e.msg, "Repository name required.")
            raise
        finally:
            app.close()

    @test.raises(exc.BossArgumentError)
    def test_rm_source_bad_label(self):
        try:
            app = get_test_app(argv=['rm-source', 'test-bogus'])
            app.setup()
            app.run()
        except exc.BossArgumentError as e:
            self.eq(e.msg, "Unknown source repository.")
            raise
        finally:
            app.close()

    def test_clean(self):
        os.system('touch %s/test_file.boss.bak' % self.tmp_dir)
        app = get_test_app(argv=['clean', self.tmp_dir])
        app.setup()
        app.run()
        app.close()

        self.eq(os.path.exists('%s/test_file.boss.bak' % self.tmp_dir), False)

    @test.raises(exc.BossArgumentError)
    def test_clean_missing_project(self):
        try:
            app = get_test_app(argv=['clean'])
            app.setup()
            app.run()
        except exc.BossArgumentError as e:
            self.eq(e.msg, "Project path required.")
            raise
        finally:
            app.close()


    def test_zz_missing_data_dir(self):
        app = get_test_app(argv=['templates'])
        app.setup()
        shutil.rmtree(app.config.get('boss', 'data_dir'))
        app.validate_config()
        app.close()





"""Tests for @project@."""

import unittest
#from nose.tools import ok_, eq_, raises
#from nose import SkipTest
    
class @module.capitalize@TestCase(unittest.TestCase):
    def setUp(self):
        pass
        
    def tearDown(self):
        pass
        
    def test_@module@(self):
        # do something to test @module@
        pass



from cement.utils import test
from boss.core import exc
from boss.cli.main import main

class CLIMainTestCase(test.CementTestCase):
    def test_main_no_args(self):
        main()

    def test_main_template_error(self):
        main(['create', '-t', 'bogus:bogus_template', self.tmp_dir])

    def test_main_argument_error(self):
        main(['create'])






from setuptools import setup, find_packages
import sys, os
from cement.utils import version
from boss import VERSION

LONG = """
Boss is a development utility that provides quick access to reusable project
templates for any language.
"""

setup(name='boss',
    version=VERSION,
    description="Baseline Open Source Software Templates",
    long_description=LONG,
    classifiers=[],
    keywords='',
    author='BJ Dierkes',
    author_email='derks@datafolklabs.com',
    url='http://boss.rtfd.org',
    license='BSD',
    packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
    include_package_data=True,
    zip_safe=False,
    test_suite='nose.collector',
    install_requires=[
        ### Required to build documentation
        # 'sphinx',
        #
        ### Required for testing
        # 'nose',
        # 'coverage',
        #
        ### Required to function
        'cement',
        ],
    setup_requires=[],
    entry_points="""
    [console_scripts]
    boss = boss.cli.main:main
    """,
    namespace_packages=[],
    )



"""Tests for boss.core.exc."""

from cement.utils import test
from boss.core import exc

class ExceptionTestCase(test.CementTestCase):
    @test.raises(exc.BossError)    
    def test_boss_error(self):
        try:
            raise exc.BossError("BossError Test")
        except exc.BossError as e:
            test.eq(e.msg, "BossError Test")
            test.eq(e.__str__(), "BossError Test")
            raise
    
    @test.raises(exc.BossConfigError)    
    def test_boss_config_error(self):
        try:
            raise exc.BossConfigError("BossConfigError Test")
        except exc.BossConfigError as e:
            test.eq(e.msg, "BossConfigError Test")
            test.eq(e.__str__(), "BossConfigError Test")
            raise
    
    @test.raises(exc.BossRuntimeError)    
    def test_boss_runtime_error(self):
        try:
            raise exc.BossRuntimeError("BossRuntimeError Test")
        except exc.BossRuntimeError as e:
            test.eq(e.msg, "BossRuntimeError Test")
            test.eq(e.__str__(), "BossRuntimeError Test")
            raise
    
    @test.raises(exc.BossArgumentError)    
    def test_boss_argument_error(self):
        try:
            raise exc.BossArgumentError("BossArgumentError Test")
        except exc.BossArgumentError as e:
            test.eq(e.msg, "BossArgumentError Test")
            test.eq(e.__str__(), "BossArgumentError Test")
            raise
    
    @test.raises(exc.BossTemplateError)    
    def test_boss_template_error(self):
        try:
            raise exc.BossTemplateError("BossTemplateError Test")
        except exc.BossTemplateError as e:
            test.eq(e.msg, "BossTemplateError Test")
            test.eq(e.__str__(), "BossTemplateError Test")
            raise
    